# Dikkat lütfen

Bu deney OpenSesame'nin eski bir sürümü ile hazırlandı.

Endişelenmeyin! Bu durum sorunlara yol açmayacak. Ancak, deneyinizi güvende olmak için yeni bir isimle kaydetmenizi öneriyorum.

Ne yapmak istersiniz?

[Deneyi şimdi kaydet](opensesame://action.save){: .important-button} <br />
[OpenSesame 3'teki yenilikler](new:html://osdoc.cogsci.nl/3.2/important-changes-3/){: .button} <br />

ya da:

[Bu mesajı sonsuza kadar yoksay](opensesame://event.os3n_dismiss_old_experiment){: .dismiss-button}
